Welcome to the cesard documentation!
====================================

cesard contains central functionalities for creating Synthetic Aperture Radar (SAR) Analysis Ready Data (ARD) products.
See for example `s1ard <https://github.com/SAR-ARD/s1ard>`_ for Sentinel-1 ARD processing.

.. toctree::
    :maxdepth: 2

    general/index.rst
    api/index.rst
    about/index.rst
    tocs.rst
